individual_analysis <-
function (fit, id, Y, pctl, samplecoloring, genecoloring, genetexts, 
    genesymbols, topcount_thresholds, geneinfo = NULL, topN, 
    rankset = rankset, k = NULL, do_rle = FALSE, do_pval = TRUE, 
    do_ctlpval = TRUE, do_projection = FALSE, do_variance = TRUE, 
    do_counttable = TRUE, do_ranktable = TRUE, rankbybeta = FALSE, 
    initialize_collapsed = FALSE) 
{
    if (is.null(k)) 
        kstring = ""
    else kstring = paste(" (K = ", k, ")", sep = "")
    if (is.null(k)) 
        kstring2 = ""
    else kstring2 = paste("k", k, sep = "")
    if (is.null(rankset)) 
        rankset = rep(TRUE, ncol(Y))
    if (do_rle) {
        exprs = filenames = matrix("", 1, 2)
        filenames[1, 1] = "rleY.png"
        filenames[1, 2] = "rleYc.png"
        exprs[1, 1] = "ruv_rle(Y, XZW=cbind(fit$X,fit$Z,fit$W), coloring=samplecoloring)"
        exprs[1, 2] = "ruv_rle(Y[,fit$ctl,drop=FALSE], XZW=cbind(fit$X,fit$Z,fit$W), coloring=samplecoloring)"
        hdynamicplotmat(paste("RLE Plots", kstring, sep = ""), 
            paste(id, kstring2, "rle", sep = ""), exprs, filenames, 
            headers = c("Y", "Y_c"), dir = id, initialize_collapsed = initialize_collapsed, 
            width = max(480, round(480 * nrow(Y)/75)))
    }
    if (do_pval) {
        exprs = filenames = matrix("", 3, 5)
        filenames[1, 1] = "unadjhist.png"
        filenames[1, 2] = "ebayeshist.png"
        filenames[1, 3] = "rsvarhist.png"
        filenames[1, 4] = "rsvarebayeshist.png"
        filenames[1, 5] = "evarhist.png"
        filenames[2, 1] = "unadjplot.png"
        filenames[2, 2] = "ebayesplot.png"
        filenames[2, 3] = "rsvarplot.png"
        filenames[2, 4] = "rsvarebayesplot.png"
        filenames[2, 5] = "evarplot.png"
        filenames[3, 1] = "unadjlogplot.png"
        filenames[3, 2] = "ebayeslogplot.png"
        filenames[3, 3] = "rsvarlogplot.png"
        filenames[3, 4] = "rsvarebayeslogplot.png"
        filenames[3, 5] = "evarlogplot.png"
        exprs[1, 1] = "ruv_pvalhist(fit$p)"
        exprs[1, 2] = "ruv_pvalhist(fit$p.ebayes)"
        exprs[1, 3] = "ruv_pvalhist(fit$p.rsvar)"
        exprs[1, 4] = "ruv_pvalhist(fit$p.rsvar.ebayes)"
        exprs[1, 5] = "ruv_pvalhist(fit$p.evar)"
        exprs[2, 1] = "ruv_pvalplot(fit$p, coloring=genecoloring, symbols=genesymbols, texts=genetexts)"
        exprs[2, 2] = "ruv_pvalplot(fit$p.ebayes, coloring=genecoloring, symbols=genesymbols, texts=genetexts)"
        exprs[2, 3] = "ruv_pvalplot(fit$p.rsvar, coloring=genecoloring, symbols=genesymbols, texts=genetexts)"
        exprs[2, 4] = "ruv_pvalplot(fit$p.rsvar.ebayes, coloring=genecoloring, symbols=genesymbols, texts=genetexts)"
        exprs[2, 5] = "ruv_pvalplot(fit$p.evar, coloring=genecoloring, symbols=genesymbols, texts=genetexts)"
        exprs[3, 1] = "ruv_pvalplot(fit$p, coloring=genecoloring, symbols=genesymbols, texts=genetexts, logged=TRUE)"
        exprs[3, 2] = "ruv_pvalplot(fit$p.ebayes, coloring=genecoloring, symbols=genesymbols, texts=genetexts, logged=TRUE)"
        exprs[3, 3] = "ruv_pvalplot(fit$p.rsvar, coloring=genecoloring, symbols=genesymbols, texts=genetexts, logged=TRUE)"
        exprs[3, 4] = "ruv_pvalplot(fit$p.rsvar.ebayes, coloring=genecoloring, symbols=genesymbols, texts=genetexts, logged=TRUE)"
        exprs[3, 5] = "ruv_pvalplot(fit$p.evar, coloring=genecoloring, symbols=genesymbols, texts=genetexts, logged=TRUE)"
        hdynamicplotmat(paste("P-values", kstring, sep = ""), 
            paste(id, kstring2, "pval", sep = ""), exprs, filenames, 
            headers = c("standard", "ebayes", "rsvar", "rsvar ebayes", 
                "evar"), dir = id, initialize_collapsed = initialize_collapsed)
    }
    if (do_ctlpval) {
        exprs = filenames = matrix("", 3, 5)
        filenames[1, 1] = "unadjhist.png"
        filenames[1, 2] = "ebayeshist.png"
        filenames[1, 3] = "rsvarhist.png"
        filenames[1, 4] = "rsvarebayeshist.png"
        filenames[1, 5] = "evarhist.png"
        filenames[2, 1] = "unadjplot.png"
        filenames[2, 2] = "ebayesplot.png"
        filenames[2, 3] = "rsvarplot.png"
        filenames[2, 4] = "rsvarebayesplot.png"
        filenames[2, 5] = "evarplot.png"
        filenames[3, 1] = "unadjlogplot.png"
        filenames[3, 2] = "ebayeslogplot.png"
        filenames[3, 3] = "rsvarlogplot.png"
        filenames[3, 4] = "rsvarebayeslogplot.png"
        filenames[3, 5] = "evarlogplot.png"
        exprs[1, 1] = "ruv_pvalhist(fit$p[fit$ctl])"
        exprs[1, 2] = "ruv_pvalhist(fit$p.ebayes[fit$ctl])"
        exprs[1, 3] = "ruv_pvalhist(fit$p.rsvar[fit$ctl])"
        exprs[1, 4] = "ruv_pvalhist(fit$p.rsvar.ebayes[fit$ctl])"
        exprs[1, 5] = "ruv_pvalhist(fit$p.evar[fit$ctl])"
        exprs[2, 1] = "ruv_pvalplot(fit$p[fit$ctl], coloring=genecoloring[fit$ctl], symbols=genesymbols[fit$ctl], texts=genetexts[fit$ctl])"
        exprs[2, 2] = "ruv_pvalplot(fit$p.ebayes[fit$ctl], coloring=genecoloring[fit$ctl], symbols=genesymbols[fit$ctl], texts=genetexts[fit$ctl])"
        exprs[2, 3] = "ruv_pvalplot(fit$p.rsvar[fit$ctl], coloring=genecoloring[fit$ctl], symbols=genesymbols[fit$ctl], texts=genetexts[fit$ctl])"
        exprs[2, 4] = "ruv_pvalplot(fit$p.rsvar.ebayes[fit$ctl], coloring=genecoloring[fit$ctl], symbols=genesymbols[fit$ctl], texts=genetexts[fit$ctl])"
        exprs[2, 5] = "ruv_pvalplot(fit$p.evar[fit$ctl], coloring=genecoloring[fit$ctl], symbols=genesymbols[fit$ctl], texts=genetexts[fit$ctl])"
        exprs[3, 1] = "ruv_pvalplot(fit$p[fit$ctl], coloring=genecoloring[fit$ctl], symbols=genesymbols[fit$ctl], texts=genetexts[fit$ctl], logged=TRUE)"
        exprs[3, 2] = "ruv_pvalplot(fit$p.ebayes[fit$ctl], coloring=genecoloring[fit$ctl], symbols=genesymbols[fit$ctl], texts=genetexts[fit$ctl], logged=TRUE)"
        exprs[3, 3] = "ruv_pvalplot(fit$p.rsvar[fit$ctl], coloring=genecoloring[fit$ctl], symbols=genesymbols[fit$ctl], texts=genetexts[fit$ctl], logged=TRUE)"
        exprs[3, 4] = "ruv_pvalplot(fit$p.rsvar.ebayes[fit$ctl], coloring=genecoloring[fit$ctl], symbols=genesymbols[fit$ctl], texts=genetexts[fit$ctl], logged=TRUE)"
        exprs[3, 5] = "ruv_pvalplot(fit$p.evar[fit$ctl], coloring=genecoloring[fit$ctl], symbols=genesymbols[fit$ctl], texts=genetexts[fit$ctl], logged=TRUE)"
        hdynamicplotmat(paste("P-values (Controls)", kstring, 
            sep = ""), paste(id, kstring2, "pvalctl", sep = ""), 
            exprs, filenames, headers = c("standard", "ebayes", 
                "rsvar", "rsvar ebayes", "evar"), dir = id, initialize_collapsed = initialize_collapsed)
    }
    if (do_projection) {
        exprs = filenames = matrix("", 1, 6)
        filenames[1, 1] = "projection.png"
        filenames[1, 2] = "topprojection.png"
        filenames[1, 3] = "topprojection.ebayes.png"
        filenames[1, 4] = "topprojection.rsvar.png"
        filenames[1, 5] = "topprojection.rsvar.ebayes.png"
        filenames[1, 6] = "topprojection.evar.png"
        if (rankbybeta) 
            filenames = cbind(filenames, "topprojection.beta.png")
        exprs[1, 1] = "ruv_projectionplot(fit$byx, fit$alpha, fit$bwx, coloring=genecoloring, symbols=genesymbols, texts=genetexts)"
        exprs[1, 2] = "ruv_topprojectionplot(fit$byx, fit$alpha, fit$bwx, fit$p, rankset=rankset)"
        exprs[1, 3] = "ruv_topprojectionplot(fit$byx, fit$alpha, fit$bwx, fit$p.ebayes, rankset=rankset)"
        exprs[1, 4] = "ruv_topprojectionplot(fit$byx, fit$alpha, fit$bwx, fit$p.rsvar, rankset=rankset)"
        exprs[1, 5] = "ruv_topprojectionplot(fit$byx, fit$alpha, fit$bwx, fit$p.rsvar.ebayes, rankset=rankset)"
        exprs[1, 6] = "ruv_topprojectionplot(fit$byx, fit$alpha, fit$bwx, fit$p.evar, rankset=rankset)"
        if (rankbybeta) 
            exprs = cbind(exprs, "ruv_topprojectionplot(fit$byx, fit$alpha, fit$bwx, -abs(fit$betahat), rankset=rankset)")
        headers = c("Standard Coloring", "standard", "ebayes", 
            "rsvar", "rsvar ebayes", "evar")
        if (rankbybeta) 
            headers = c(headers, "betahat")
        hdynamicplotmat(paste("Projection Plots", kstring, sep = ""), 
            paste(id, kstring2, "projplots", sep = ""), exprs, 
            filenames, headers = headers, dir = id, initialize_collapsed = initialize_collapsed)
    }
    if (do_variance) {
        exprs = filenames = matrix("", 1, 6)
        filenames[1, 1] = "varianceroot.png"
        filenames[1, 2] = "topvarianceroot.png"
        filenames[1, 3] = "topvariancerootebayes.png"
        filenames[1, 4] = "topvariancerootrsvar.png"
        filenames[1, 5] = "topvariancerootrsvarebayes.png"
        filenames[1, 6] = "topvariancerootevar.png"
        if (rankbybeta) 
            filenames = cbind(filenames, "topvariancerootbeta.png")
        exprs[1, 1] = "ruv_varianceplot(fit, fit$varbetahat, coloring=genecoloring, symbols=genesymbols, texts=genetexts, trans=fourthroot, xlab=\"(sigma^2 hat)^(1/4)\", ylab=\"(betahat^2)^(1/4)\")"
        exprs[1, 2] = "ruv_topvarianceplot(fit, fit$p, fit$varbetahat, trans=fourthroot, xlab=\"(sigma^2 hat)^(1/4)\", ylab=\"(betahat^2)^(1/4)\", rankset=rankset)"
        exprs[1, 3] = "ruv_topvarianceplot(fit, fit$p.ebayes, fit$varbetahat.ebayes, trans=fourthroot, xlab=\"(sigma^2 hat)^(1/4)\", ylab=\"(betahat^2)^(1/4)\", rankset=rankset)"
        exprs[1, 4] = "ruv_topvarianceplot(fit, fit$p.rsvar, fit$varbetahat.rsvar, trans=fourthroot, xlab=\"(sigma^2 hat)^(1/4)\", ylab=\"(betahat^2)^(1/4)\", rankset=rankset)"
        exprs[1, 5] = "ruv_topvarianceplot(fit, fit$p.rsvar.ebayes, fit$varbetahat.rsvar.ebayes, trans=fourthroot, xlab=\"(sigma^2 hat)^(1/4)\", ylab=\"(betahat^2)^(1/4)\", rankset=rankset)"
        exprs[1, 6] = "ruv_topvarianceplot(fit, fit$p.evar, fit$varbetahat.evar, trans=fourthroot, xlab=\"(sigma^2 hat)^(1/4)\", ylab=\"(betahat^2)^(1/4)\", rankset=rankset)"
        if (rankbybeta) 
            exprs = cbind(exprs, "ruv_topvarianceplot(fit, -abs(fit$betahat), fit$varbetahat, trans=fourthroot, xlab=\"(sigma^2 hat)^(1/4)\", ylab=\"(betahat^2)^(1/4)\", rankset=rankset)")
        headers = c("Standard Coloring", "standard", "ebayes", 
            "rsvar", "rsvar ebayes", "evar")
        if (rankbybeta) 
            headers = c(headers, "betahat")
        hdynamicplotmat(paste("Variance Plots", kstring, sep = ""), 
            paste(id, kstring2, "varplots", sep = ""), exprs, 
            filenames, headers = headers, dir = id, initialize_collapsed = initialize_collapsed)
    }
    if (do_counttable) {
        if (!is.null(pctl)) {
            rankcount = ruv_toprankcount(fit$p[1, rankset], pctl[rankset], 
                topcount_thresholds)
            rankcount.ebayes = ruv_toprankcount(fit$p.ebayes[1, 
                rankset], pctl[rankset], topcount_thresholds)
            rankcount.rsvar = ruv_toprankcount(fit$p.rsvar[1, 
                rankset], pctl[rankset], topcount_thresholds)
            rankcount.rsvar.ebayes = ruv_toprankcount(fit$p.rsvar.ebayes[1, 
                rankset], pctl[rankset], topcount_thresholds)
            rankcount.evar = ruv_toprankcount(fit$p.evar[1, rankset], 
                pctl[rankset], topcount_thresholds)
            rankcount.beta = ruv_toprankcount(-abs(fit$betahat[1, 
                rankset]), pctl[rankset], topcount_thresholds)
            if (rankbybeta) 
                hdynamictablerownest("Number of Top-ranked Positive Controls", 
                  paste(id, kstring2, "counts", sep = ""), list(rankcount, 
                    rankcount.ebayes, rankcount.rsvar, rankcount.rsvar.ebayes, 
                    rankcount.evar, rankcount.beta), headers = c("standard", 
                    "ebayes", "rsvar", "rsvar ebayes", "evar", 
                    "betahat"), google = FALSE, initialize_collapsed = initialize_collapsed)
            else hdynamictablerownest("Number of Top-ranked Positive Controls", 
                paste(id, kstring2, "counts", sep = ""), list(rankcount, 
                  rankcount.ebayes, rankcount.rsvar, rankcount.rsvar.ebayes, 
                  rankcount.evar), headers = c("standard", "ebayes", 
                  "rsvar", "rsvar ebayes", "evar"), google = FALSE, 
                initialize_collapsed = initialize_collapsed)
        }
    }
    if (do_ranktable) {
        geneinfo = rbind(geneinfo, index = 1:length(fit$p))
        ranktable = ruv_topranktable(fit$p, beta = fit$betahat, 
            info = geneinfo, N = topN, rankset = rankset)
        ranktable.ebayes = ruv_topranktable(fit$p.ebayes, beta = fit$betahat, 
            info = geneinfo, N = topN, rankset = rankset)
        ranktable.rsvar = ruv_topranktable(fit$p.rsvar, beta = fit$betahat, 
            info = geneinfo, N = topN, rankset = rankset)
        ranktable.rsvar.ebayes = ruv_topranktable(fit$p.rsvar.ebayes, 
            beta = fit$betahat, info = geneinfo, N = topN, rankset = rankset)
        ranktable.evar = ruv_topranktable(fit$p.evar, beta = fit$betahat, 
            info = geneinfo, N = topN, rankset = rankset)
        ranktable.beta = ruv_topranktable(fit$p, beta = fit$betahat, 
            rankby = -abs(fit$betahat), info = geneinfo, N = topN, 
            rankset = rankset)
        ranktable.ebayes.beta = ruv_topranktable(fit$p.ebayes, 
            beta = fit$betahat, rankby = -abs(fit$betahat), info = geneinfo, 
            N = topN, rankset = rankset)
        ranktable.rsvar.beta = ruv_topranktable(fit$p.rsvar, 
            beta = fit$betahat, rankby = -abs(fit$betahat), info = geneinfo, 
            N = topN, rankset = rankset)
        ranktable.rsvar.ebayes.beta = ruv_topranktable(fit$p.rsvar.ebayes, 
            beta = fit$betahat, rankby = -abs(fit$betahat), info = geneinfo, 
            N = topN, rankset = rankset)
        ranktable.evar.beta = ruv_topranktable(fit$p.evar, beta = fit$betahat, 
            rankby = -abs(fit$betahat), info = geneinfo, N = topN, 
            rankset = rankset)
        hdynamictablerownest(paste("Top-ranked Genes", kstring, 
            sep = ""), paste(id, kstring2, "ranks", sep = ""), 
            list(ranktable, ranktable.ebayes, ranktable.rsvar, 
                ranktable.rsvar.ebayes, ranktable.evar), headers = c("standard", 
                "ebayes", "rsvar", "rsvar ebayes", "evar"), google = TRUE, 
            initialize_collapsed = initialize_collapsed)
        if (rankbybeta) 
            hdynamictablerownest(paste("Top-ranked Genes, Ranked by betahat", 
                kstring, sep = ""), paste(id, kstring2, "betaranks", 
                sep = ""), list(ranktable.beta, ranktable.ebayes.beta, 
                ranktable.rsvar.beta, ranktable.rsvar.ebayes.beta, 
                ranktable.evar.beta), headers = c("standard", 
                "ebayes", "rsvar", "rsvar ebayes", "evar"), google = TRUE, 
                initialize_collapsed = initialize_collapsed)
    }
}
