ruv_starter_analysis <-
function (Y, X, ctl, Z = 1, eta = NULL, pctl = NULL, genecoloring = NULL, 
    samplecoloring = NULL, genetexts = NULL, sampletexts = NULL, 
    genesymbols = NULL, samplesymbols = NULL, geneinfo = NULL, 
    rankbybeta = FALSE, topN = 40, topcount_thresholds = c(20, 
        40, 60, 80, 100), rankset = NULL, kset = c(1, 2, 3, 5, 
        7, 10, 15, 20, 30, 50, 75, 100, 200, 500, 1000, 2000, 
        5000, 10000), factorset = 1:5, bin = 10, do_general = TRUE, 
    do_unadjusted = TRUE, do_ruv2 = TRUE, do_ruv4 = TRUE, do_ruvinv = TRUE, 
    do_ruvrinv = TRUE, do_pptable = TRUE, outdir = "html", initialize_collapsed = FALSE, 
    webtitle = "RUV Starter Analysis", inputcheck = TRUE, verbose = FALSE) 
{
    if (verbose) 
        cat("Input Check\n")
    if (inputcheck) 
        inputcheck1(Y, X, Z, ctl)
    if (verbose) 
        cat("RUV1\n")
    Y = RUV1(Y, eta, ctl)
    if (verbose) 
        cat("Setup\n")
    m = nrow(Y)
    n = ncol(Y)
    nc = sum(ctl)
    Yc = Y[, ctl, drop = FALSE]
    if (ncol(X) > 1) {
        cat("This routine is not meant for X with more than one column.\n")
        return()
    }
    if ((nc < m - 1) & do_ruvinv) {
        cat("The number of negative controls is less than the number of samples.  It is not possible to run RUV-inv.  Please set do_ruvinv to FALSE.\n")
        return()
    }
    if (is.null(Z)) {
        q = 0
    }
    else if (length(Z) == 1) {
        if (Z == 1) {
            Z = matrix(1, m, 1)
            q = 1
        }
    }
    else {
        q = ncol(Z)
    }
    kset = kset[kset < m - q - 1]
    kset = kset[kset < sum(ctl)]
    factorset = factorset[factorset < m - q - 1]
    fullctl = rep(T, n)
    if (is.null(rankset)) 
        rankset = rep(TRUE, n)
    topcount_thresholds = topcount_thresholds[topcount_thresholds < 
        sum(rankset)]
    if (is.null(genecoloring)) {
        genecoloring = rep(NA, n)
        genecoloring[ctl] = "green4"
        if (!is.null(pctl)) 
            genecoloring[pctl] = "purple"
    }
    unadj = RUV2(Y, X, ctl, 0, Z = Z, inputcheck = FALSE)
    W_ctl = unadj$fullW[, 1:min(ncol(unadj$fullW), nc)]
    W_fullctl = RUV2(Y, X, fullctl, 0, Z = Z, inputcheck = FALSE)$fullW
    if (verbose) 
        cat("read misc files\n")
    filelist = scan(paste(system.file(package = "ruv.extras"), 
        "misc/filelist.txt", sep = "/"), what = "character", 
        quiet = TRUE)
    combinedheaders = scan(paste(system.file(package = "ruv.extras"), 
        "misc/combinedheaders.txt", sep = "/"), what = "character", 
        sep = "\n", quiet = TRUE)
    filestokeep = c(1, 2, 33, 3:32)
    filelist = filelist[filestokeep]
    combinedheaders = combinedheaders[filestokeep]
    hstart(overwrite = TRUE, basedir = outdir, title = webtitle, 
        bodyfiles = paste(system.file(package = "ruv.htmllatex"), 
            "misc/javascript.js", sep = "/"))
    if (verbose) 
        cat("General Info\n")
    if (do_general) {
        hsectionstart("generalsec", "General Info", initialize_collapsed = initialize_collapsed)
        general_info(m, n, nc, Y, Yc, X, Z, ctl, W_fullctl, W_ctl, 
            samplecoloring, genecoloring, sampletexts, genetexts, 
            samplesymbols, genesymbols, initialize_collapsed = initialize_collapsed)
        hsectionstop()
    }
    if (verbose) 
        cat("Unadjusted\n")
    if (do_unadjusted) {
        hsectionstart("unadjsec", "Unadjusted", initialize_collapsed = initialize_collapsed)
        fit = variance_adjust(unadj, bin = bin)
        individual_analysis(fit, "unadj", Y, pctl, samplecoloring, 
            genecoloring, genetexts, genesymbols, topcount_thresholds, 
            geneinfo, topN, rankset = rankset, do_rle = TRUE, 
            rankbybeta = rankbybeta, initialize_collapsed = initialize_collapsed)
        hsectionstop()
    }
    if (verbose) 
        cat("RUV-2\n")
    if (do_ruv2) {
        if (verbose) 
            cat("Combined\n")
        hsectionstart("combruv2sec", "RUV-2 Combined Analyses", 
            initialize_collapsed = initialize_collapsed)
        if (!is.null(pctl)) 
            counttables = ruv2toprankcounttables(Y, X, ctl, pctl, 
                Z = Z, bin = bin, thresholds = topcount_thresholds, 
                rankset = rankset, inputcheck = FALSE)
        else counttables = NULL
        combined_analysis(counttables, filelist, combinedheaders, 
            "ruv2", kset, rankbybeta = rankbybeta, initialize_collapsed = initialize_collapsed)
        hsectionstop()
        if (verbose) 
            cat("Individual\n")
        hsectionstart("ruv2sec", "RUV-2 Individual Analyses", 
            initialize_collapsed = initialize_collapsed)
        W = RUV2(Y, X, ctl, 0, Z = Z, inputcheck = FALSE)$fullW
        for (k in kset) {
            if (verbose) 
                cat(k, ", ", sep = "")
            hcat("<br>\n")
            hsubsectionstart(paste("ruv2k", k, "sec", sep = ""), 
                paste("RUV-2 K =", k), initialize_collapsed = initialize_collapsed)
            hcat("<br>\n")
            fit = RUV2(Y, X, ctl, k, Z = Z, fullW = W, inputcheck = FALSE)
            fit = variance_adjust(fit, bin = bin)
            individual_analysis(fit, "ruv2", Y, pctl, samplecoloring, 
                genecoloring, genetexts, genesymbols, topcount_thresholds, 
                geneinfo, topN, rankset = rankset, k = k, do_rle = TRUE, 
                do_projection = TRUE, rankbybeta = rankbybeta, 
                initialize_collapsed = initialize_collapsed)
            hsubsectionstop()
        }
        if (verbose) 
            cat("\n")
        hsectionstop()
    }
    if (verbose) 
        cat("RUV-4\n")
    if (do_ruv4) {
        if (verbose) 
            cat("Combined\n")
        hsectionstart("combruv4sec", "RUV-4 Combined Analyses", 
            initialize_collapsed = initialize_collapsed)
        if (!is.null(pctl)) 
            counttables = ruv4toprankcounttables(Y, X, ctl, pctl, 
                Z = Z, bin = bin, thresholds = topcount_thresholds, 
                rankset = rankset, inputcheck = FALSE)
        else counttables = NULL
        combined_analysis(counttables, filelist, combinedheaders, 
            "ruv4", kset, rankbybeta = rankbybeta, initialize_collapsed = initialize_collapsed)
        hsectionstop()
        if (verbose) 
            cat("Individual\n")
        hsectionstart("ruv4sec", "RUV-4 Individual Analyses", 
            initialize_collapsed = initialize_collapsed)
        W0 = RUV4(Y, X, ctl, 0, Z = Z, inputcheck = FALSE)$fullW0
        for (k in kset) {
            if (verbose) 
                cat(k, ", ", sep = "")
            hsubsectionstart(paste("ruv4k", k, "sec", sep = ""), 
                paste("RUV-4 K =", k), initialize_collapsed = initialize_collapsed)
            fit = RUV4(Y, X, ctl, k, Z = Z, fullW0 = W0, inputcheck = FALSE)
            fit = variance_adjust(fit, bin = bin)
            individual_analysis(fit, "ruv4", Y, pctl, samplecoloring, 
                genecoloring, genetexts, genesymbols, topcount_thresholds, 
                geneinfo, topN, rankset = rankset, k = k, do_rle = TRUE, 
                do_projection = TRUE, rankbybeta = rankbybeta, 
                initialize_collapsed = initialize_collapsed)
            hsubsectionstop()
        }
        if (verbose) 
            cat("\n")
        hsectionstop()
    }
    if (verbose) 
        cat("RUV-inv\n")
    if (do_ruvinv) {
        hsectionstart("ruvinvsec", "RUV-inv", initialize_collapsed = initialize_collapsed)
        fit = RUVinv(Y, X, ctl, Z = Z, inputcheck = FALSE)
        fit = variance_adjust(fit, bin = bin)
        individual_analysis(fit, "ruvinv", Y, pctl, samplecoloring, 
            genecoloring, genetexts, genesymbols, topcount_thresholds, 
            geneinfo, topN, rankset = rankset, do_projection = TRUE, 
            rankbybeta = rankbybeta, initialize_collapsed = initialize_collapsed)
        hsectionstop()
    }
    if (verbose) 
        cat("RUV-rinv\n")
    if (do_ruvrinv) {
        hsectionstart("ruvrinvsec", "RUV-rinv", initialize_collapsed = initialize_collapsed)
        fit = RUVrinv(Y, X, ctl, Z = Z, inputcheck = FALSE)
        fit = variance_adjust(fit, bin = bin)
        individual_analysis(fit, "ruvrinv", Y, pctl, samplecoloring, 
            genecoloring, genetexts, genesymbols, topcount_thresholds, 
            geneinfo, topN, rankset = rankset, do_projection = TRUE, 
            rankbybeta = rankbybeta, initialize_collapsed = initialize_collapsed)
        hsectionstop()
    }
    if (verbose) 
        cat("Projection Plot Table\n")
    if (do_pptable) {
        hsectionstart("projplottablesec", "Projection Plot Table", 
            initialize_collapsed = initialize_collapsed)
        fullfit = RUVinv(Y, X, ctl, Z = Z, inputcheck = FALSE)
        projplottable(fullfit, c(0, kset), factorset, genecoloring, 
            genetexts, genesymbols, initialize_collapsed = initialize_collapsed)
        hsectionstop()
    }
    hstop()
}
