\name{ruv_starter_analysis}
\alias{ruv_starter_analysis}

\title{
RUV starter analysis
}

\description{
A script that performs many RUV analyses, generates plots, tables, etc., and nicely formats the output in an html file.  This script is useful for getting a quick first look at your data; it should not be considered to provide a final or complete analysis.  More information about the usage of this script can be found in the how-to at \href{http://www.stat.berkeley.edu/~johann/ruv}{http://www.stat.berkeley.edu/~johann/ruv}. 
}

\usage{
ruv_starter_analysis(Y, X, ctl, Z = 1, eta = NULL, pctl = NULL, genecoloring = NULL, samplecoloring = NULL, genetexts = NULL, sampletexts = NULL, genesymbols = NULL, samplesymbols = NULL, geneinfo = NULL, rankbybeta = FALSE, topN = 40, topcount_thresholds = c(20, 40, 60, 80, 100), rankset = NULL, kset = c(1, 2, 3, 5, 7, 10, 15, 20, 30, 50, 75, 100, 200, 500, 1000, 2000, 5000, 10000), factorset = 1:5, bin = 10, do_general = TRUE, do_unadjusted = TRUE, do_ruv2 = TRUE, do_ruv4 = TRUE, do_ruvinv = TRUE, do_ruvrinv = TRUE, do_pptable=TRUE, outdir = "html", initialize_collapsed = FALSE, webtitle = "RUV Starter Analysis", inputcheck = TRUE, verbose = FALSE)
}

\arguments{
  \item{Y}{
     The data.  A m by n matrix, where m is the number of samples and n is the number of features.
}
  \item{X}{
     The factor of interest.  A m by 1 matrix, where m is the number of samples. 
}
  \item{ctl}{
     The negative controls.  A logical vector of length n.  
}
  \item{Z}{
     Any additional covariates to include in the model.  Either a m by q matrix of covariates, or simply 1 (the default) for an intercept term.
}
  \item{eta}{
     Gene-wise (as oposed to sample-wise) covariates.  These covariates are adjusted for by RUV-1 before any further analysis proceeds.  A matrix with n columns.
}
  \item{pctl}{
     Positive controls.  A logical vector of length n.
}
  \item{genecoloring}{
    A vector of length n.  The colors to use when plotting genes.
}
  \item{samplecoloring}{
    A vector of length m.  The colors to use when plotting samples.
}    
  \item{genetexts}{
    A vector of length n.  Any text to be used in place of symbols, when plotting genes.  Elements that are NA are plotted as symbols.
}
  \item{sampletexts}{
    A vector of length m.  Any text to be used in place of symbols, when plotting samples.  Elements that are NA are plotted as symbols.
}
  \item{genesymbols}{
    A vector of length n.  The plot symbols to use when plotting genes.
}
  \item{samplesymbols}{
    A vector of length m.  The plot symbols to use when plotting symbols.
}
  \item{geneinfo}{
    A matrix with n columns.  Each row should contain some information about the genes (such as their names) for use in tables.
}
  \item{rankbybeta}{
    Should the analysis include a ranking of the features based on the absolue value of estimated effect size (betahat)?
}
  \item{topN}{
    The number of top-ranked genes to include in tables.
}
  \item{topcount_thresholds}{
    The thresholds to use when counting the number of top-ranked positive controls.
}
  \item{rankset}{
    The genes to be considered when determining which are top-ranked.  A logical vector.  NULL implies all genes.
}
  \item{kset}{
    Which values of K should be considered.
}
  \item{factorset}{
    Which factors should be included in the projection plot table.
}
  \item{bin}{
    The bin size in the method of empirical variances.
}
  \item{do_general}{
    Should the "General" analysis be performed?
}
  \item{do_unadjusted}{
    Should the "unadjusted" analysis be performed?
}
  \item{do_ruv2}{
    Should the RUV-2 analysis be performed?
}
  \item{do_ruv4}{
    Should the RUV-4 analysis be performed?
}
  \item{do_ruvinv}{
    Should the RUV-inv analysis be performed?
}
  \item{do_ruvrinv}{
    Should the RUV-rinv analysis be performed?
}
  \item{do_pptable}{
    Should the factor projection plot table be created?
}
  \item{outdir}{
    Directory where the web page should be written.
}
  \item{initialize_collapsed}{
    Should the web page be created so that only headers are shown, and must be manually expanded?
}
  \item{webtitle}{
    The title of the web page.
}
  \item{inputcheck}{
     Perform a basic sanity check on the inputs, and issue a warning if there is a problem.
}
  \item{verbose}{
    Verbose output.
}
}

\value{
  Does not return a (meaningful) value.  Generates a web page.
}

\author{
Johann Gagnon-Bartsch \email{johann@stat.berkeley.edu}
}

\note{
It is highly recommended to read the how-to at \href{http://www.stat.berkeley.edu/~johann/ruv}{http://www.stat.berkeley.edu/~johann/ruv}.
}

\note{
The ruv_starter_analysis script should not be considered part of the "core" of the ruv package. It may be more properly thought of as a demo of what one can do with the ruv package (albeit an elaborate and particularly useful demo). Thus, you are encouraged to modify this script to fit your own needs.  Moreover, this script will not be carefully maintained. In future releases, this script may be modified, perhaps in a way that is not backwards-compatible, perhaps beyond recognition, and may even be omitted entirely.
}

